@@ -1,6 +1,6 @@
 #
 #  Copyright (C) 2009 Friedrich Leisch
-#  $Id: bootstrap.R 4640 2010-11-24 11:54:47Z leisch $
+#  $Id: bootstrap.R 4807 2012-05-02 10:19:24Z leisch $
 #
 
 bootFlexclust <- function(x, k, nboot=100, correct=TRUE, seed=NULL,
@@ -44,8 +44,14 @@ bootFlexclust <- function(x, k, nboot=100, correct=TRUE, seed=NULL,
         
         for(l in 1:nk)
         {
-            cl1 <- getModel(s1, l)
-            cl2 <- getModel(s2, l)
+            if(nk>1){
+                cl1 <- getModel(s1, l)
+                cl2 <- getModel(s2, l)
+            }
+            else{
+                cl1 <- s1
+                cl2 <- s2
+            }
 
             clust1[,l] <- clusters(cl1, newdata=x)
             clust2[,l] <- clusters(cl2, newdata=x)
@@ -54,7 +60,7 @@ bootFlexclust <- function(x, k, nboot=100, correct=TRUE, seed=NULL,
             cent2[[l]] <- cl2@centers
 
             rand[l] <- randIndex(table(clust1[,l], clust2[,l]),
-                              correct=correct)
+                                 correct=correct)
         }
         list(cent1=cent1, cent2=cent2, clust1=clust1, clust2=clust2,
              rand=rand)
@@ -76,7 +82,11 @@ bootFlexclust <- function(x, k, nboot=100, correct=TRUE, seed=NULL,
         dim(cent1[[l]]) <- dim(cent2[[l]]) <- c(k[l], ncol(x), nboot)
     }
 
-    rand <- t(sapply(z, function(x) x$rand))
+    if(nk > 1)
+        rand <- t(sapply(z, function(x) x$rand))
+    else
+        rand <- as.matrix(sapply(z, function(x) x$rand))
+
     colnames(rand) <- k
     
     if(verbose) cat("\n")
@@ -86,80 +96,82 @@ bootFlexclust <- function(x, k, nboot=100, correct=TRUE, seed=NULL,
         rand=rand, call=MYCALL)
 }
 
+
 ###**********************************************************
 
+
 ## <FIXME> Delete non-multicore code base eventually
 
-bootFlexclust.orig <- function(x, k, nboot=100, verbose=TRUE, correct=TRUE,
-                          seed=NULL, ...)
-{
-    MYCALL <- match.call()
+## bootFlexclust.orig <- function(x, k, nboot=100, verbose=TRUE, correct=TRUE,
+##                           seed=NULL, ...)
+## {
+##     MYCALL <- match.call()
 
-    if(!is.null(seed)) set.seed(seed)
+##     if(!is.null(seed)) set.seed(seed)
     
-    nk <- length(k)
-    nx <- nrow(x)
+##     nk <- length(k)
+##     nx <- nrow(x)
 
-    index1 <- matrix(integer(1), nrow=nx, ncol=nboot)
-    index2 <- index1
+##     index1 <- matrix(integer(1), nrow=nx, ncol=nboot)
+##     index2 <- index1
 
-    for(b in 1:nboot){
-        index1[,b] <- sample(1:nx, nx, replace=TRUE)
-        index2[,b] <- sample(1:nx, nx, replace=TRUE)
-    }
+##     for(b in 1:nboot){
+##         index1[,b] <- sample(1:nx, nx, replace=TRUE)
+##         index2[,b] <- sample(1:nx, nx, replace=TRUE)
+##     }
 
-    clust1 <- array(integer(1), dim=c(nx, nk, nboot))
-    clust2 <- clust1
+##     clust1 <- array(integer(1), dim=c(nx, nk, nboot))
+##     clust2 <- clust1
     
-    cent1 <- list()
-    for(l in 1:nk)
-    {
-        cent1[[l]] <- array(double(1), dim=c(k[l], ncol(x), nboot))
-    }
-    cent2 <- cent1
+##     cent1 <- list()
+##     for(l in 1:nk)
+##     {
+##         cent1[[l]] <- array(double(1), dim=c(k[l], ncol(x), nboot))
+##     }
+##     cent2 <- cent1
 
-    rand <- matrix(double(1), nrow=nboot, ncol=nk)
-    colnames(rand) <- k
+##     rand <- matrix(double(1), nrow=nboot, ncol=nk)
+##     colnames(rand) <- k
 
-    for(b in 1:nboot)
-    {
-        if(verbose){
-            if((b %% 100) == 0)
-                cat("\n")
-            if((b %% 10) == 0)
-                cat(b, "")
-        }
+##     for(b in 1:nboot)
+##     {
+##         if(verbose){
+##             if((b %% 100) == 0)
+##                 cat("\n")
+##             if((b %% 10) == 0)
+##                 cat(b, "")
+##         }
 
-        i1 <- index1[,b]
-        i2 <- index2[,b]
+##         i1 <- index1[,b]
+##         i2 <- index2[,b]
 
-        s1 <- stepFlexclust(x[i1,,drop=FALSE], k=k, verbose=FALSE,
-                            simple=TRUE, ...)
-        s2 <- stepFlexclust(x[i2,,drop=FALSE], k=k, verbose=FALSE,
-                            simple=TRUE, ...)
+##         s1 <- stepFlexclust(x[i1,,drop=FALSE], k=k, verbose=FALSE,
+##                             simple=TRUE, ...)
+##         s2 <- stepFlexclust(x[i2,,drop=FALSE], k=k, verbose=FALSE,
+##                             simple=TRUE, ...)
         
-        for(l in 1:nk)
-        {
-            cl1 <- getModel(s1, l)
-            cl2 <- getModel(s2, l)
+##         for(l in 1:nk)
+##         {
+##             cl1 <- getModel(s1, l)
+##             cl2 <- getModel(s2, l)
 
-            clust1[,l,b] <- clusters(cl1, newdata=x)
-            clust2[,l,b] <- clusters(cl2, newdata=x)
+##             clust1[,l,b] <- clusters(cl1, newdata=x)
+##             clust2[,l,b] <- clusters(cl2, newdata=x)
 
-            cent1[[l]][,,b] <- cl1@centers
-            cent2[[l]][,,b] <- cl2@centers
+##             cent1[[l]][,,b] <- cl1@centers
+##             cent2[[l]][,,b] <- cl2@centers
 
-            rand[b,l] <- randIndex(table(clust1[,l,b], clust2[,l,b]),
-                                   correct=correct)
-        }
-    }
+##             rand[b,l] <- randIndex(table(clust1[,l,b], clust2[,l,b]),
+##                                    correct=correct)
+##         }
+##     }
     
-    if(verbose) cat("\n")
+##     if(verbose) cat("\n")
 
-    new("bootFlexclust", k=k, centers1=cent1, centers2=cent2,
-        cluster1=clust1, cluster2=clust2, index1=index1, index2=index2,
-        rand=rand, call=MYCALL)
-}
+##     new("bootFlexclust", k=k, centers1=cent1, centers2=cent2,
+##         cluster1=clust1, cluster2=clust2, index1=index1, index2=index2,
+##         rand=rand, call=MYCALL)
+## }
 
 ## </FIXME>
 
@@ -205,52 +217,3 @@ function(x, data, ...){
 
 
 
-
-###**********************************************************
-
-setGeneric("randIndex", function(x, y, correct=TRUE)
-           standardGeneric("randIndex"))
-
-setMethod("randIndex", signature(x="flexclust", y="flexclust"),
-function(x, y, correct=TRUE){
-    randIndex(table(clusters(x), clusters(y)), correct=correct)
-})
-
-setMethod("randIndex", signature(x="flexclust", y="integer"),
-function(x, y, correct=TRUE){
-    randIndex(table(clusters(x), y), correct=correct)
-})
-
-setMethod("randIndex", signature(x="integer", y="flexclust"),
-function(x, y, correct=TRUE){
-    randIndex(table(x, clusters(y)), correct=correct)
-})
-
-setMethod("randIndex", signature(x="integer", y="integer"),
-function(x, y, correct=TRUE){
-    randIndex(table(x, y), correct=correct)
-})
-
-setMethod("randIndex", signature(x="table", y="missing"),
-function(x, y, correct=TRUE)
-{
-    if(length(dim(x))!=2)
-        stop("Argument x needs to be a 2-dimensional table.")
-    
-    n <- sum(x)
-    ni <- apply(x, 1, sum)
-    nj <- apply(x, 2, sum)
-    n2 <- choose(n, 2)
-
-    if(correct){
-        nis2 <- sum(choose(ni[ni > 1], 2))
-        njs2 <- sum(choose(nj[nj > 1], 2))
-        rand <- (sum(choose(x[x > 1], 2)) -
-                 (nis2 * njs2)/n2)/((nis2 + njs2)/2 - (nis2 * njs2)/n2)
-    }
-    else
-        rand <- 1 + (sum(x^2) - (sum(ni^2) + sum(nj^2))/2)/n2
-
-    return(rand)
-})
-
