@@ -1,23 +1,22 @@
 ##
 ## Copyright (C) 2008 Friedrich Leisch
-## $Id: bundestag.R 4366 2009-06-18 13:43:44Z leisch $
+## $Id: bundestag.R 4464 2009-11-24 11:57:41Z leisch $
 ##
 bundestag <- function(year, second=TRUE, percent=TRUE, nazero=TRUE,
                       state=FALSE)
 {
-    year <- match.arg(as.character(year), c("2002", "2005"))
-    tempenv <- new.env()
-    if(year=="2002"){
-        load(system.file("data/btw2002.RData", package="flexclust"),
-             envir=tempenv)
-        x <- get("btw2002", envir=tempenv)
-    }
-    else{
-        load(system.file("data/btw2005.RData", package="flexclust"),
-             envir=tempenv)
-        x <- get("btw2005", envir=tempenv)
-    }
+    year <- match.arg(as.character(year), c("2002", "2005", "2009"))
 
+    getData <- function(year){
+        tempenv <- new.env()
+        load(system.file(paste("data/btw", year, ".RData", sep=""),
+                         package="flexclust"),
+             envir=tempenv)
+        get(paste("btw", year, sep=""), envir=tempenv)
+    }
+        
+    x <- getData(year)
+    
     if(is.logical(state)){
         if(state) return(x$state)
     }
